@@ -7,3 +7,7 @@ class DjangoLiveDashboardConfig(AppConfig):
     asgi_started = False
     asgi_shutdown = False
     redis = None
+
+    def ready(self):
+        from .worker import event_worker_thread
+        event_worker_thread.start()
